abstochkin API documentation

# abstochkin

Agent-based (or Particle-based) Stochastic Kinetics.

View Source

     1""" Agent-based (or Particle-based) Stochastic Kinetics. """
     2
     3#  Copyright (c) 2024-2025, Alex Plakantonakis.
     4#
     5#  This program is free software: you can redistribute it and/or modify
     6#  it under the terms of the GNU General Public License as published by
     7#  the Free Software Foundation, either version 3 of the License, or
     8#  (at your option) any later version.
     9#
    10#  This program is distributed in the hope that it will be useful,
    11#  but WITHOUT ANY WARRANTY; without even the implied warranty of
    12#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    13#  GNU General Public License for more details.
    14#
    15#  You should have received a copy of the GNU General Public License
    16#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
    17
    18from .base import AbStochKin
    19
    20__version__ = '0.1.3'
    21__license__ = "GPL-3.0"